@@ -10,7 +10,7 @@ pub const INSTRUCTION_ADD_USER_TO_AIRDROP_ACCOUNT:u8=7;
 pub const INSTRUCTION_SERUM_SWAP:u8=8;
 pub const INSTRUCTION_CLOSE_PPU:u8=9;
 pub const INSTRUCTION_UPDATE_STATE_TURING_MASHINE:u8=10;
-pub const INSTRUCTION_UPDATE_AMOUNT_PPU:u8=11;
+pub const INSTRUCTION_UPDATE_AMOUNT_TURING_MASHINE:u8=11;
 pub const INSTRUCTION_STAKE_LP_TOKEN:u8=12;
 pub const INSTRUCTION_UPDATE_SPLU_PPU_STABEL_COINS:u8=13;
 pub const INSTRUCTION_DEPOSIT_SERUM:u8=14;
@@ -20,7 +20,6 @@ pub const INSTRUCTION_UPDATE_STATE_SPLU_TURING_MASHINE_WITH_PARAM:u8=17;
 pub const INSTRUCTION_UPDATE_STATE_AIRDROP_ACCOUNT:u8=18;
 pub const INSTRUCTION_INITIALIZE_PORTFOLIO:u8=19;
 pub const INSTRUCTION_CREATE_INIT_PPU:u8=20;
-pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
 pub const INSTRUCTION_UPDATE_STATE_INITIALIZE_PPM:u8=21;
 pub const INSTRUCTION_ADD_ASSET_TO_PORTFOLIO:u8=22;
 pub const INSTRUCTION_ADD_SPLU_TO_PPU:u8=23;
@@ -38,7 +37,9 @@ pub const INSTRUCTION_RESET_SPLU_TERTIARY_PPU:u8=34;
 pub const INSTRUCTION_CLAIM_REWARDS:u8=35;
 pub const INSTRUCTION_TRANSFER_REWARDS:u8=36;
 pub const INSTRUCTION_INVEST_MORE:u8=37;
-pub const INSTRUCTION_CLOSE_TURING_MASHINE:u8=38;
+pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
+pub const INSTRUCTION_CLOSE_TURING_MASHINE:u8=39;
+pub const INSTRUCTION_CLOSE_PPM:u8=40;
 pub const EXTERNAL_INSTRUCTION_WITHDRAW_SABER: u8 = 3;
 pub const WITHDRAW_INSTRUCTION_SABER: u8 = 3;
 pub const EXTERNAL_INSTRUCTION_APPROVE_SPL: u8 = 4;
